@@ -35,6 +35,7 @@ CACHE_PATH = None           #符号表缓存路径
 CERT_PASSWORD = None        #证书密码
 NOTIFICATION_EMAILS = None  #
 WITHOUT_POD_INSTALL = False #不需要$pod install
+IGNORE_ASSETS = False       #需要忽略assets文件夹        
 JIRA_URL = None             #jira bug地址
 MODULE_KEYWORD = []         #组件库关键字
 TO_USER = []
@@ -81,6 +82,7 @@ def _print_helpdoc():
     print("     \033[0;34m[-l]\033[0m or \033[0;34m[--link]\033[0m  \tjira link url")
     print("     \033[0;34m[-k]\033[0m or \033[0;34m[--keyword]\033[0m  \tkeyword od module")
     print("     \033[0;34m[--no-pod]\033[0m  \tdo without pod install")
+    print("     \033[0;34m[--ignore-assets]\033[0m  \tgit pull with ignoring assets folder")
 
 def _check_fastlane():
     print("检查是否安装fastlane，如果没有则立即安装fastlane和pgyer插件")
@@ -176,6 +178,7 @@ def pull(*parameters):
         successlog("pull shell success")
     except BaseException as error:
         faillog("pull shell failed:" + format(error))
+        sys.exit()
     #拉子模块
     pullsubmodule(parameters)
 
@@ -183,8 +186,8 @@ def pullsubmodule(*parameters):
     """
     切换分支+拉取子模块代码+pod install
     """
-    global WITHOUT_POD_INSTALL
-    Package().pull_submodule()
+    global WITHOUT_POD_INSTALL,IGNORE_ASSETS
+    Package().pull_submodule(IGNORE_ASSETS)
     Package().run_extension_sh(['prepare_flutter.sh'])
 
     if IOSProjectTool().have_podfile():
@@ -283,7 +286,8 @@ class Usage(Exception):
 def main(prog=None,args=None):
     global PROJECT_ADDRESS, PROJECT_BRANCH, TEST_PLATFORM, NET_ENV, PROJECT_VERSION, PROJECT_BUILD,\
            NOTIFICATION_EMAILS, PACKAGE_BRANCH, DEV_BRANCH, LOG_OR_NOT,TAG_NAME,PACKAGE_ORDER, CACHE_PATH, \
-           CERT_PASSWORD, WITHOUT_POD_INSTALL,JIRA_URL,MODULE_KEYWORD,CC_USER,TO_USER,PROJECT_FOLDER_NAME
+           CERT_PASSWORD, WITHOUT_POD_INSTALL,JIRA_URL,MODULE_KEYWORD,CC_USER,TO_USER,PROJECT_FOLDER_NAME, \
+               IGNORE_ASSETS
 
     #处理系统方法
     sys_action(sys.argv)  
@@ -292,7 +296,7 @@ def main(prog=None,args=None):
     shortargs = 'a:p:b:e:n:d:m:gk:c:t:o:w:l:' #短选项模式
     longargs = ['address=', 'platform=', 'branch=', 'environment=', 'version=', \
                 'build=', 'email=', 'log', 'package=','code=','tag=','order=',\
-                'cache=','password=','no-pod','link=','keyword='] #长选项模式
+                'cache=','password=','no-pod','link=','keyword=','ignore-assets'] #长选项模式
     try:
         try:
             opts, args = getopt.getopt(args, shortargs, longargs)
@@ -340,6 +344,8 @@ def main(prog=None,args=None):
                     WITHOUT_POD_INSTALL = True
                 elif opt in ("-l", "--link"):
                     JIRA_URL = arg
+                elif opt in ("--ignore-assets"):
+                    IGNORE_ASSETS = True
             # zuche-Develop
             # None
             # None
